@@ -30,9 +30,39 @@ import trino.exceptions
 import trino.client
 import trino.logging
 from trino.transaction import Transaction, IsolationLevel, NO_TRANSACTION
+from trino.exceptions import (
+    Warning,
+    Error,
+    InterfaceError,
+    DatabaseError,
+    DataError,
+    OperationalError,
+    IntegrityError,
+    InternalError,
+    ProgrammingError,
+    NotSupportedError,
+)
 
-
-__all__ = ["connect", "Connection", "Cursor"]
+__all__ = [
+    # https://www.python.org/dev/peps/pep-0249/#globals
+    "apilevel",
+    "threadsafety",
+    "paramstyle",
+    "connect",
+    "Connection",
+    "Cursor",
+    # https://www.python.org/dev/peps/pep-0249/#exceptions
+    "Warning",
+    "Error",
+    "InterfaceError",
+    "DatabaseError",
+    "DataError",
+    "OperationalError",
+    "IntegrityError",
+    "InternalError",
+    "ProgrammingError",
+    "NotSupportedError",
+]
 
 
 apilevel = "2.0"
@@ -76,7 +106,8 @@ class Connection(object):
         max_attempts=constants.DEFAULT_MAX_ATTEMPTS,
         request_timeout=constants.DEFAULT_REQUEST_TIMEOUT,
         isolation_level=IsolationLevel.AUTOCOMMIT,
-        verify=True
+        verify=True,
+        http_session=None
     ):
         self.host = host
         self.port = port
@@ -86,8 +117,11 @@ class Connection(object):
         self.schema = schema
         self.session_properties = session_properties
         # mypy cannot follow module import
-        self._http_session = trino.client.TrinoRequest.http.Session()
-        self._http_session.verify = verify
+        if http_session is None:
+            self._http_session = trino.client.TrinoRequest.http.Session()
+            self._http_session.verify = verify
+        else:
+            self._http_session = http_session
         self.http_headers = http_headers
         self.http_scheme = http_scheme
         self.auth = auth
@@ -197,6 +231,12 @@ class Cursor(object):
     def connection(self):
         return self._connection
 
+    @property
+    def info_uri(self):
+        if self._query is not None:
+            return self._query.info_uri
+        return None
+
     @property
     def description(self):
         if self._query.columns is None:
