@@ -33,6 +33,10 @@ class Http503Error(HttpError):
     pass
 
 
+class Http504Error(HttpError):
+    pass
+
+
 class TrinoError(Exception):
     pass
 
@@ -41,6 +45,10 @@ class TimeoutError(Exception):
     pass
 
 
+class TrinoAuthError(Exception):
+    pass
+
+
 class TrinoQueryError(Exception):
     def __init__(self, error, query_id=None):
         self._error = error
